# komfovent-api-python

Basic implementation of Komfovent C6 local controller.  
  
Completed:
- Auth
- reading basic settings and model version
- reading parts of current state (current mode, current fan speed, temperature sensors)
- setting operation mode
  
To do: everything else  

### Contributions
Opening PR is welcome and encouraged, I do not regularly check Github, so ping free to ping me through github email.